/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.*;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * <p>Child factory for {@link CommentAllocation}</p> <p>Possible children are {@link Comment}, {@link CommentValue}
 * and {@link AllocationTime}</p>
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({
        "isobus project taskdata node name comment=Comment ({0})"
    })
public class CommentAllocationChildFactory extends ChildFactory<Node> {

    private final CommentAllocation commentAllocation;
    private static final String COMMENT_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_comment.png";

    public CommentAllocationChildFactory(CommentAllocation commentAllocation) {
        this.commentAllocation = commentAllocation;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Comment (CCT)
        Comment comment = (Comment) commentAllocation.getCommentId();
        if (comment != null) {
            String description = Bundle.isobus_project_taskdata_node_name_comment(comment.getDesignator());
            toPopulate.add(new IsobusCommonNode(Children.create(new CommentChildFactory(comment), true), comment, COMMENT_ICON, description));
        }

        //CommentListValue CCL
        CommentListValue commentListValue = (CommentListValue) commentAllocation.getCommentListValueId();
        if (commentListValue != null) {
            toPopulate.add(new CommentListValueNode(commentListValue));
        }

        //AllocationTime (ASP)
        AllocationTime allocationTime = commentAllocation.getAllocationTime();
        if (allocationTime != null) {
            toPopulate.add(new AllocationStampNode(allocationTime));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }

    /**
     * <p>Child factory for the {@link Comment} object</p> <p>Possible children
     * are {@link CommentGroup} and {@link CommentListValue}
     *
     * @author Gerben Feenstra
     */
    @NbBundle.Messages({
        "isobus project taskdata node name comment group=Comment group ({0})"
    })
    static class CommentChildFactory extends ChildFactory<Node> {

        private static final String COMMENT_GROUP_ICON = "";
        private final Comment comment;

        public CommentChildFactory(Comment comment) {
            this.comment = comment;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            //CommentListValue CCL
            for (CommentListValue commentListValue : comment.getCommentListValues()) {
                toPopulate.add(new CommentListValueNode(commentListValue));
            }
            //CommentGroup CCG
            CommentGroup commentGroup = (CommentGroup) comment.getCommentGroupId();
            if (commentGroup != null) {
                String description = Bundle.isobus_project_taskdata_node_name_comment_group(commentGroup.getDesignator());
                toPopulate.add(new IsobusCommonNode(Children.LEAF, commentGroup, COMMENT_GROUP_ICON, description));
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
