/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DataLog;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import nl.cloudfarming.client.isobus.model.ValuePresentation;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for the {@link DataLog} object</p>
 * <p>Possible children are {@link ValuePresentation} and {@link DeviceElement}</p>
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
public class DataLogChildFactory extends ChildFactory<Node>{

    private final DataLog dataLog;
    
    public DataLogChildFactory(DataLog dataLog){
        this.dataLog = dataLog;
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //DeviceElement (DET)
        DeviceElement deviceElement = (DeviceElement) dataLog.getDeviceElementId();
        if(deviceElement != null){
            toPopulate.add(new DeviceElementNode(deviceElement));
        }
        
        //ValuePresentation VPN
        ValuePresentation valuePresentation = (ValuePresentation) dataLog.getValuePresentationId();
        if(valuePresentation != null){
            toPopulate.add(new ValuePresentationNode(valuePresentation));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }
    
    
    
}
