/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.DeviceAllocation;
import nl.cloudfarming.client.isobus.model.IsobusDevice;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * <p>Child factory for {@link DeviceAllocation} object</p>
 * <p>Possible children {@link AllocationTime} and {@link IsobusDevice}</p>
 * @author Gerben Feenstra
 */
public class DeviceAllocationChildFactory extends ChildFactory<Node> {

    private final DeviceAllocation deviceAllocation;

    public DeviceAllocationChildFactory(DeviceAllocation deviceAllocation) {
        this.deviceAllocation = deviceAllocation;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {

        //AllocationStamp (ASP)
        AllocationTime allocationTime = deviceAllocation.getAllocationStamp();
        if (allocationTime != null) {
            toPopulate.add(new AllocationStampNode(allocationTime));
        }
        //Device DVC
        IsobusDevice isobusDevice = (IsobusDevice) deviceAllocation.getDeviceId();
        if(isobusDevice != null){
            toPopulate.add(new DeviceNode(isobusDevice));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
