/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.DeviceElement;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;
import org.openide.util.lookup.Lookups;

/**
 * Node for the {@link DeviceElement} object
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"isobus project taskdata node name device element=Device element ({0})"})
public class DeviceElementNode extends AbstractNode {

    private static final String DEVICE_ELEMENT_CHILDNODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_device_element.png";

    public DeviceElementNode(DeviceElement deviceElement) {
        super(Children.create(new DeviceElementChildFactory(deviceElement), true), Lookups.fixed(deviceElement));
        setName(Bundle.isobus_project_taskdata_node_name_device_element(deviceElement.getDesignator()));
        setIconBaseWithExtension(DEVICE_ELEMENT_CHILDNODE_ICON);
    }

    /**
     * <p>Child factory for {@link DeviceObjectReference}</p> <p>Possible
     * children are {@link DeviceElement}</p>
     *
     * @author Gerben Feenstra
     */
    @NbBundle.Messages("isobus project taskdata aggregatenode name device object references=DeviceObject references")
    static class DeviceElementChildFactory extends ChildFactory<Node> {

        private static final String DEVICE_OBJECT_REFERENCE_AGGRGATE_NODE_ICON = "";
        private final DeviceElement deviceElement;

        public DeviceElementChildFactory(DeviceElement deviceElement) {
            this.deviceElement = deviceElement;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            if (!deviceElement.getDeviceObjectReferences().isEmpty()) {
                String displayName = Bundle.isobus_project_taskdata_aggregatenode_name_device_object_references();
                Children deviceObjectReferenceChildren = Children.create(new AggregateNodeChildFactory<>(deviceElement.getDeviceObjectReferences()), true);
                toPopulate.add(new IsobusAggregateNode(deviceObjectReferenceChildren, DEVICE_OBJECT_REFERENCE_AGGRGATE_NODE_ICON, displayName));
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
