/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.CulturalPractice;
import nl.cloudfarming.client.isobus.model.OperationTechnique;
import nl.cloudfarming.client.isobus.model.OperationTechniquePractice;
import nl.cloudfarming.client.isobus.model.OperationTechniqueReference;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.NbBundle;

/**
 * Child factory for {@link OperationTechniquePractice} Possible children are {@link OperationTechnique}
 * and {@link CulturalPractice}
 *
 * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
 */
@NbBundle.Messages({"isobus project taskdata node name cultural practice=Cultural practice ({0})"
})
public class OperationTechniquePracticeChildFactory extends ChildFactory<Node> {

    private static final String CULTURAL_PRACTICE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_cultural_practice.png";
    private final OperationTechniquePractice techniquePractice;

    public OperationTechniquePracticeChildFactory(OperationTechniquePractice techniquePractice) {
        this.techniquePractice = techniquePractice;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //CulturalPractice (CPC)
        CulturalPractice culturalPractice = (CulturalPractice) techniquePractice.getCulturalPracticeIdRef();
        if (culturalPractice != null) {
            String description = Bundle.isobus_project_taskdata_node_name_cultural_practice(culturalPractice.getDesignator());
            Children cpcChildren = Children.create(new CulturalPracticeChildFactory(culturalPractice), true);
            toPopulate.add(new IsobusCommonNode(cpcChildren, culturalPractice, CULTURAL_PRACTICE_ICON, description));
        }

        //OperationTechnique (OTQ)
        OperationTechnique operationTechnique = (OperationTechnique) techniquePractice.getOperationTechniqueIdRef();
        if (operationTechnique != null) {
            toPopulate.add(new OperationTechniqueNode(operationTechnique));
        }

        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }

    /**
     * <p>Child factory for {@link CulturalPractice}</p> <p>Possible children {@link OperationTechniqueReference}
     * </p>
     *
     * @author Merijn Zengers <Merijn.Zengers@gmail.nl>
     */
    static class CulturalPracticeChildFactory extends ChildFactory<Node> {

        private final CulturalPractice culturalPractice;

        public CulturalPracticeChildFactory(CulturalPractice culturalPractice) {
            this.culturalPractice = culturalPractice;
        }

        @Override
        protected boolean createKeys(List<Node> toPopulate) {
            for (OperationTechniqueReference reference : culturalPractice.getOperationTechniques()) {
                OperationTechnique operationTechnique = (OperationTechnique) reference.getOperationTechniqueIdRef();
                if (operationTechnique != null) {
                    toPopulate.add(new OperationTechniqueNode(operationTechnique));
                }
            }
            return true;
        }

        @Override
        protected Node createNodeForKey(Node key) {
            return key;
        }
    }
}
