/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.*;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Children;
import org.openide.nodes.Node;
import org.openide.util.Lookup;
import org.openide.util.NbBundle.Messages;

/**
 *
 * @author Gerben Feenstra
 */
@Messages({
    "isobus project taskdata aggregatenode name commentallocation=Comment allocations",
    "isobus project taskdata aggregatenode name connection=Connections",
    "isobus project taskdata aggregatenode name deviceallocation=Device allocations",
    "isobus project taskdata aggregatenode name datalog=Datalogs",
    "isobus project taskdata aggregatenode name productallocation=Product allocations",
    "isobus project taskdata aggregatenode name treatmentzone=Treatment zone",
    "isobus project taskdata aggregatenode name time=Times",
    "isobus project taskdata aggregatenode name workerallocation=Worker allocations",
    "isobus project taskdata node name grid=Grid ({0})",
    "isobus project taskdata node name opertechpractice=Operation technique practice",
    "isobus project taskdata node name timelog=Time log ({0})"
})
public class TaskChildFactory extends ChildFactory<Node> {

    // Childnode icons
    private static final String GRID_CHILDNODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_grid.png";
    private static final String OPERTECHPRACTICE_CHILDNODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_operTechPractice.png";
    private static final String TIMELOG_CHILDNODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_timelog.png";
    // Aggregate node icons
    private static final String WORKERALLOCATION_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_workerallocation.png";
    private static final String COMMENTALLOCATION_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_comment_allocations.png";
    private static final String CONNECTION_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_connections.png";
    private static final String DEVICEALLOCATION_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_device_allocation.png";
    private static final String DATALOG_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_datalog.png";
    private static final String PRODUCTALLOCATION_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_product_allocations.png";
    private static final String TIME_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_time.png";
    private static final String TREATMENTZONE_AGGREGATENODE_ICON = "nl/cloudfarming/client/isobus/tree/isobus_taskdata_treatmentzone.png";
    // Aggregate node displaynames
    static final String COMMENTALLOCATION_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_commentallocation();
    static final String CONNECTION_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_connection();
    static final String DEVICEALLOCATION_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_deviceallocation();
    static final String DATALOG_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_datalog();
    static final String PRODUCTALLOCATION_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_productallocation();
    static final String TREATMENTZONE_AGGREGATENODE_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_treatmentzone();
    static final String OPERATION_TECH_PRACTICE_NAME = Bundle.isobus_project_taskdata_node_name_opertechpractice();
    static final String TIME_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_time();
    static final String WORKERALLOCATION_NAME = Bundle.isobus_project_taskdata_aggregatenode_name_workerallocation();
    private final IsobusTask isobusTask;

    public TaskChildFactory(IsobusTask isobusTask) {
        this.isobusTask = isobusTask;
    }

    @Override
    protected boolean createKeys(List<Node> toPopulate) {


        //Customer CTR
        if (isobusTask.getCustomerIdRef() != null) {
            toPopulate.add(new CustomerNode((Customer) isobusTask.getCustomerIdRef()));
        }

        //Farm FRM
        if (isobusTask.getFarmIdRef() != null) {
            toPopulate.add(new FarmNode((IsobusFarm) isobusTask.getFarmIdRef()));
        }

        //Partfield PFD
        if (isobusTask.getPartfieldIdRef() != null) {
            toPopulate.add(new PartFieldNode((IsobusPartField) isobusTask.getPartfieldIdRef()));
        }

        //Worker WKR
        if (isobusTask.getResponsibleWorkerIdRef() != null) {
            toPopulate.add(new WorkerNode((IsobusWorker) isobusTask.getResponsibleWorkerIdRef()));
        }

        // CommentAllocation (CAN)
        if (!isobusTask.getCAN().isEmpty()) {
            Children commentAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getCAN()), true);
            toPopulate.add(new IsobusAggregateNode(commentAllocationChildren, COMMENTALLOCATION_AGGREGATENODE_ICON, COMMENTALLOCATION_AGGREGATENODE_NAME));
        }

        // Connection (CNN)
        if (!isobusTask.getCNN().isEmpty()) {
            Children connectionAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getCNN()), true);
            toPopulate.add(new IsobusAggregateNode(connectionAllocationChildren, CONNECTION_AGGREGATENODE_ICON, CONNECTION_AGGREGATENODE_NAME));
        }

        // DeviceAllocation (DAN)
        if (!isobusTask.getDAN().isEmpty()) {
            Children deviceAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getDAN()), true);
            toPopulate.add(new IsobusAggregateNode(deviceAllocationChildren, DEVICEALLOCATION_AGGREGATENODE_ICON, DEVICEALLOCATION_AGGREGATENODE_NAME));
        }

        // DataLogTrigger (DLT)
        if (!isobusTask.getDLT().isEmpty()) {
            Children dataLogAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getDLT()), true);
            toPopulate.add(new IsobusAggregateNode(dataLogAllocationChildren, DATALOG_AGGREGATENODE_ICON, DATALOG_AGGREGATENODE_NAME));
        }


        // IsobusTreatmentZoneGrid (GRD)
        IsobusGrid grid = isobusTask.getGRD();
        if (grid != null) {
            Lookup.getDefault().lookup(Object.class);
            String displayName = Bundle.isobus_project_taskdata_node_name_grid(grid.getFilename());
            toPopulate.add(new IsobusCommonNode(Children.LEAF, grid, GRID_CHILDNODE_ICON, displayName));
        }

        // OperTechPractice (OTP)
        OperationTechniquePractice operTechPractice = isobusTask.getOTP();
        if (operTechPractice != null) {
            Children operTechPracticeChildren = Children.create(new OperationTechniquePracticeChildFactory(operTechPractice), true);
            toPopulate.add(new IsobusAggregateNode(operTechPracticeChildren, OPERTECHPRACTICE_CHILDNODE_ICON, OPERATION_TECH_PRACTICE_NAME));
        }

        // ProductAllocation (PAN)
        if (!isobusTask.getPAN().isEmpty()) {
            Children productAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getPAN()), true);
            toPopulate.add(new IsobusAggregateNode(productAllocationChildren, PRODUCTALLOCATION_AGGREGATENODE_ICON, PRODUCTALLOCATION_AGGREGATENODE_NAME));
        }

        // TimeLog (TLG) 
        // There is only 1 timelog (despite it being a list)
        // TODO: Investigate; Wrong assumption? There can be more then 1 timelog in one isobustaskdata, but can there be more then on in a single isobus task?
        if (isobusTask.getTLG() != null && !isobusTask.getTLG().isEmpty()) {
            TimeLog timeLog = isobusTask.getTLG().get(0);
            String displayName = Bundle.isobus_project_taskdata_node_name_timelog(timeLog.getFilename());
            toPopulate.add(new IsobusCommonNode(Children.LEAF, timeLog, TIMELOG_CHILDNODE_ICON, displayName));
        }

        // Time (TIM)
        if (!isobusTask.getTIM().isEmpty()) {
            Children timeChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getTIM()), true);
            toPopulate.add(new IsobusAggregateNode(timeChildren, TIME_AGGREGATENODE_ICON, TIME_NAME));
        }


        // TreatmentZone (TZN)
        if (!isobusTask.getTZN().isEmpty()) {
            Children treatmentZoneChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getTZN()), true);
            toPopulate.add(new IsobusAggregateNode(treatmentZoneChildren, TREATMENTZONE_AGGREGATENODE_ICON, TREATMENTZONE_AGGREGATENODE_NAME));
        }

        // WorkerAllocation (WAN)
        if (!isobusTask.getWAN().isEmpty()) {
            Children workerAllocationChildren = Children.create(new AggregateNodeChildFactory<>(isobusTask.getWAN()), true);
            toPopulate.add(new IsobusAggregateNode(workerAllocationChildren, WORKERALLOCATION_AGGREGATENODE_ICON, WORKERALLOCATION_NAME));
        }
        return true;
    }

    @Override
    protected Node createNodeForKey(Node key) {
        return key;
    }
}
