/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import nl.cloudfarming.client.isobus.tree.TaskDataChildFactory;
import java.awt.Image;
import java.awt.datatransfer.Transferable;
import java.util.Arrays;
import javax.swing.Action;
import nl.cloudfarming.client.isobus.model.IsobusTaskData;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.HelpCtx;
import org.openide.util.ImageUtilities;
import org.openide.util.datatransfer.PasteType;
import org.openide.util.lookup.Lookups;
import org.openide.util.lookup.ProxyLookup;

/**
 * Root node for the {@link IsobusTaskData} 
 * @author Gerben Feenstra
 */
public class TaskDataRootNode extends FilterNode {
    
    private static final String ISOBUS_TASKDATA_NODE_ICON = "nl/cloudfarming/client/isobus/type/iso.png";
        
    public TaskDataRootNode(IsobusTaskData isobusObj, Node original)  {
        super(original,Children.create(new TaskDataChildFactory(isobusObj), true), new ProxyLookup(Lookups.fixed(isobusObj),original.getLookup()));
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(ISOBUS_TASKDATA_NODE_ICON);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }
    
    @Override
    public HelpCtx getHelpCtx() {
        return new HelpCtx("nl.cloudfarming.client.isobus.project.explorer");
    }
    
    @Override
    public PasteType getDropType(Transferable t, int action, int index) {
        return null;
    }

    @Override
    public Action[] getActions(boolean context) {
        return super.getActions(context);
    }

}
