/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.tree;

import java.util.List;
import nl.cloudfarming.client.isobus.model.AllocationTime;
import nl.cloudfarming.client.isobus.model.IsobusWorker;
import nl.cloudfarming.client.isobus.model.WorkerAllocation;
import org.openide.nodes.ChildFactory;
import org.openide.nodes.Node;

/**
 * Child factory for {@link WorkerAllocation} objects
 * Possible children {@link IsobusWorker} and {@link AllocationTime}
 * @author Gerben Feenstra
 */
public class WorkerAllocationChildFactory extends ChildFactory<Node> {

    private final WorkerAllocation workerAllocation;

    public WorkerAllocationChildFactory(WorkerAllocation workerAllocation) {
        this.workerAllocation = workerAllocation;
    }
    
    @Override
    protected boolean createKeys(List<Node> toPopulate) {
        //Worker (WKR)
        IsobusWorker worker = (IsobusWorker) workerAllocation.getWorkerIdRef();
        if(worker != null){
            toPopulate.add(new WorkerNode(worker));
        }
        
        //AllocationStamp (ASP)
        AllocationTime allocationStamp = workerAllocation.getAllocationStamp();
        if(allocationStamp != null){ 
            toPopulate.add(new AllocationStampNode(allocationStamp));
        }
        
        return true;
    }

    @Override
    protected Node createNodeForKey(Node node) {
        return node;
    }
}
